@@ -6,7 +6,7 @@ use warnings;
 
 use Log::Log4perl ':easy';
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use Moo::Role;
 
@@ -16,8 +16,8 @@ sub _printTestSuccesses {
         and exists $self->result->{details}->{runTestResult}->{successes};
     print $FH $_ for map {
         my $time = $$_{time}/1000;
-        "<testcase>\n\tname='$$_{methodName}'\n\tclassname='$$_{name}'\n\ttime='$time'\n</testcase>
-        "} (
+        "\n<testcase\n\tname='$$_{methodName}'\n\tclassname='$$_{name}'\n\ttime='$time'>\n</testcase>"} 
+        (
             ref $self->result->{details}->{runTestResult}->{successes} eq 'ARRAY'
                 ? @{$self->result->{details}->{runTestResult}->{successes}}
                 : $self->result->{details}->{runTestResult}->{successes}
@@ -29,7 +29,9 @@ sub _printTestFailures {
     return unless $self->testFailures;
     print $FH $_ for map {
       my $time = $$_{time}/1000;
-      "\n<testcase>\n\tname='$$_{methodName}'\n\tclassname='$$_{name}'\n\ttime='$time'\n\t<failure>\n\t\t<![CDATA: $$_{message}]>\n\t</failure>\n</testcase>"} 
+      my $stackTrace = '';
+      $stackTrace = $$_{stackTrace} if (defined($$_{stackTrace}));
+      "\n<testcase\n\tname='$$_{methodName}'\n\tclassname='$$_{name}'\n\ttime='$time'>\n\t<failure>\n\t\t<![CDATA[$stackTrace - $$_{message}]]>\n\t</failure>\n</testcase>"} 
     @{
       $self->testFailures
     };
@@ -45,10 +47,10 @@ sub printToJUnit {
   open my $FH, '>', $fileName
     or ERROR "Couldn't open $fileName for writing: $!";
   print $FH '<?xml version="1.0" encoding="UTF-8"?>';
-  print $FH '<testsuite name="SFDC Unit Tests">';
+  print $FH "\n".'<testsuite name="SFDC Unit Tests">';
   $self->_printTestSuccesses($FH);
   $self->_printTestFailures($FH);
-  print $FH '</testsuite>';
+  print $FH "\n".'</testsuite>';
 }
 
 1;
@@ -63,7 +65,7 @@ App::SFDC::Role::DeployResult::JUnitOutput - Provides JUnit output functionality
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
